==> igniteui-react-charts-16.16.1.tgz: package/esm2015/lib/RadialLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { AnchoredRadialSeries } from "./AnchoredRadialSeries";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { Array_$type, runOn, enumGetBox, markType, markDep } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core";
import { AnchoredRadialSeriesView } from "./AnchoredRadialSeriesView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
export let RadialLineSeries = /*@__PURE__*/ (() => {
    class RadialLineSeries extends AnchoredRadialSeries {
        constructor() {
            super();
            this.ab = RadialLineSeries.$;
        }
        get_d1() {
            return true;
        }
        bx() {
            return new RadialLineSeriesView(this);
        }
        lz(a) {
            super.lz(a);
            this.t7 = a;
        }
        ac() {
            super.ac();
        }
        preferredCategoryMode(a) {
            return 0;
        }
        kx(a, b) {
            super.kx(a, b);
            let c = b;
            c.c1();
        }
        sq(a, b) {
            super.sq(a, b);
            let c = b.bv;
            let d = b.bu;
            let e = a.f;
            let f = e.count;
            let g = new List$1(Array_$type, 2, f);
            let h = 0;
            for (let i = 0; i < f; i++) {
                let j = new Array(4);
                g.add(j);
                j[0] = this.rt.d(a.f._inner[i][0], a.f._inner[i][1], c, d);
                j[1] = this.rt.e(a.f._inner[i][0], a.f._inner[i][1], c, d);
                j[2] = this.rt.d(a.f._inner[i][0], a.f._inner[i][2], c, d);
                let k = a.f._inner[i][2];
                j[3] = this.rt.e(a.f._inner[i][0], k, c, d);
                if (k > h) {
                    h = k;
                }
            }
            let l = this.getEffectiveViewport1(b);
            this.rz.a0(this, this.sb(), runOn(this, this.ri), this.sd(b), this.se(b));
            let m = false;
            let n = this.rz.b;
            if (n != null) {
                m = true;
            }
            if (m) {
                let o = new ScalerParams(0, b.bv, b.bu, this.rl.cg, l);
                this.tp(e, -1, this.s4.count, this.rl, o, b.q);
            }
            let p = b;
            let q = p.da;
            let r = p.db;
            let s = p.c9;
            this.rz.ad(q, true, false, true, false);
            this.rz.ad(r, true, false, true, false);
            this.rz.ad(s, false, true, false, false);
            s._opacity = 0.75 * this.rz.j;
            p.c2(f, g, false, this.t8, this.sx(g, f - 1, b), p.cs.b, this.ft);
        }
        l4(a, b, c, d) {
            super.l4(a, b, c, d);
            switch (b) {
                case RadialLineSeries.$$p[0]:
                    this.mi(false);
                    this.lp();
                    break;
            }
        }
        get_s7() {
            return true;
        }
    }
    RadialLineSeries.$t = /*@__PURE__*/ markType(RadialLineSeries, 'RadialLineSeries', AnchoredRadialSeries.$);
    RadialLineSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, RadialLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:t8:ua', [UnknownValuePlotting_$type, /*@__PURE__*/ enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return RadialLineSeries;
})();
/**
 * @hidden
 */
export let RadialLineSeriesView = /*@__PURE__*/ (() => {
    class RadialLineSeriesView extends AnchoredRadialSeriesView {
        constructor(a) {
            super(a);
            this.c0 = null;
            this.c7 = new Path();
            this.c6 = new Path();
            this.c8 = new Path();
            this.c4 = new Path();
            this.c3 = new Path();
            this.c5 = new Path();
            this.c0 = a;
        }
        as() {
            super.as();
            if (!this.q) {
                this.b1.qd = Defaults.e;
            }
        }
        get da() {
            return this.c7;
        }
        get db() {
            return this.c8;
        }
        get c9() {
            return this.c6;
        }
        c1() {
            this.c7.ak = null;
            this.c6.ak = null;
            this.c8.ak = null;
            this.c4.ak = null;
            this.c3.ak = null;
            this.c5.ak = null;
            this.aq();
        }
        c2(a, b, c, d, e, f, g) {
            this.cw.sz.m(this.c7, this.c6, this.c8, a, b, c, d, e, f, g);
            this.aq();
        }
        bb() {
            super.bb();
        }
        bc() {
            super.bc();
            let a = this.bo();
            this.c3.ak = this.c6.ak;
            this.c4.ak = this.c7.ak;
            this.c5.ak = this.c8.ak;
            this.c4._stroke = a;
            this.c4.ac = this.e.fu + 3;
            this.c5._stroke = a;
            this.c5.ac = this.e.fu + 3;
            this.c3._fill = a;
            this.c3._opacity = 1;
        }
        a6(a, b) {
            super.a6(a, b);
            if (a.d) {
                if (b) {
                    a.s(this.c3);
                    a.s(this.c4);
                    a.s(this.c5);
                }
                else {
                    a.s(this.c6);
                    a.s(this.c7);
                    a.s(this.c8);
                }
            }
        }
        al(a) {
            super.al(a);
            this.e.a8.exportPathData(a, this.c7, "lowerShape", ["Lower", "Main"]);
            this.e.a8.exportPathData(a, this.c8, "upperShape", ["Upper"]);
            this.e.a8.exportPathData(a, this.c6, "translucentShape", ["Translucent"]);
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.pb = a;
            this.e.gw = 3;
            this.e.gx = 1;
            this.e.gy = 4;
            this.e.e7 = false;
        }
    }
    RadialLineSeriesView.$t = /*@__PURE__*/ markType(RadialLineSeriesView, 'RadialLineSeriesView', AnchoredRadialSeriesView.$);
    return RadialLineSeriesView;
})();

==> igniteui-react-charts-18.1.0.tgz: package/esm2015/lib/RadialLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { AnchoredRadialSeries } from "./AnchoredRadialSeries";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { Array_$type, runOn, enumGetBox, markType, markDep } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core";
import { AnchoredRadialSeriesView } from "./AnchoredRadialSeriesView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
export let RadialLineSeries = /*@__PURE__*/ (() => {
    class RadialLineSeries extends AnchoredRadialSeries {
        constructor() {
            super();
            this.ab = RadialLineSeries.$;
        }
        get_d2() {
            return true;
        }
        bx() {
            return new RadialLineSeriesView(this);
        }
        l2(a) {
            super.l2(a);
            this.ub = a;
        }
        ac() {
            super.ac();
        }
        preferredCategoryMode(a) {
            return 0;
        }
        k0(a, b) {
            super.k0(a, b);
            let c = b;
            c.c1();
        }
        su(a, b) {
            super.su(a, b);
            let c = b.bv;
            let d = b.bu;
            let e = a.f;
            let f = e.count;
            let g = new List$1(Array_$type, 2, f);
            let h = 0;
            for (let i = 0; i < f; i++) {
                let j = new Array(4);
                g.add(j);
                j[0] = this.rx.d(a.f._inner[i][0], a.f._inner[i][1], c, d);
                j[1] = this.rx.e(a.f._inner[i][0], a.f._inner[i][1], c, d);
                j[2] = this.rx.d(a.f._inner[i][0], a.f._inner[i][2], c, d);
                let k = a.f._inner[i][2];
                j[3] = this.rx.e(a.f._inner[i][0], k, c, d);
                if (k > h) {
                    h = k;
                }
            }
            let l = this.getEffectiveViewport1(b);
            this.r3.a0(this, this.sf(), runOn(this, this.rm), this.sh(b), this.si(b));
            let m = false;
            let n = this.r3.b;
            if (n != null) {
                m = true;
            }
            if (m) {
                let o = new ScalerParams(0, b.bv, b.bu, this.rp.cg, l);
                this.tt(e, -1, this.s8.count, this.rp, o, b.q);
            }
            let p = b;
            let q = p.da;
            let r = p.db;
            let s = p.c9;
            this.r3.ad(q, true, false, true, false);
            this.r3.ad(r, true, false, true, false);
            this.r3.ad(s, false, true, false, false);
            s._opacity = 0.75 * this.r3.j;
            p.c2(f, g, false, this.uc, this.s1(g, f - 1, b), p.cs.b, this.fv);
        }
        l7(a, b, c, d) {
            super.l7(a, b, c, d);
            switch (b) {
                case RadialLineSeries.$$p[0]:
                    this.ml(false);
                    this.ls();
                    break;
            }
        }
        get_tb() {
            return true;
        }
    }
    RadialLineSeries.$t = /*@__PURE__*/ markType(RadialLineSeries, 'RadialLineSeries', AnchoredRadialSeries.$);
    RadialLineSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, RadialLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:uc:ue', [UnknownValuePlotting_$type, /*@__PURE__*/ enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return RadialLineSeries;
})();
/**
 * @hidden
 */
export let RadialLineSeriesView = /*@__PURE__*/ (() => {
    class RadialLineSeriesView extends AnchoredRadialSeriesView {
        constructor(a) {
            super(a);
            this.c0 = null;
            this.c7 = new Path();
            this.c6 = new Path();
            this.c8 = new Path();
            this.c4 = new Path();
            this.c3 = new Path();
            this.c5 = new Path();
            this.c0 = a;
        }
        as() {
            super.as();
            if (!this.q) {
                this.b1.qh = Defaults.e;
            }
        }
        get da() {
            return this.c7;
        }
        get db() {
            return this.c8;
        }
        get c9() {
            return this.c6;
        }
        c1() {
            this.c7.ak = null;
            this.c6.ak = null;
            this.c8.ak = null;
            this.c4.ak = null;
            this.c3.ak = null;
            this.c5.ak = null;
            this.aq();
        }
        c2(a, b, c, d, e, f, g) {
            this.cw.s3.m(this.c7, this.c6, this.c8, a, b, c, d, e, f, g);
            this.aq();
        }
        bb() {
            super.bb();
        }
        bc() {
            super.bc();
            let a = this.bo();
            this.c3.ak = this.c6.ak;
            this.c4.ak = this.c7.ak;
            this.c5.ak = this.c8.ak;
            this.c4._stroke = a;
            this.c4.ac = this.e.fw + 3;
            this.c5._stroke = a;
            this.c5.ac = this.e.fw + 3;
            this.c3._fill = a;
            this.c3._opacity = 1;
        }
        a6(a, b) {
            super.a6(a, b);
            if (a.d) {
                if (b) {
                    a.s(this.c3);
                    a.s(this.c4);
                    a.s(this.c5);
                }
                else {
                    a.s(this.c6);
                    a.s(this.c7);
                    a.s(this.c8);
                }
            }
        }
        al(a) {
            super.al(a);
            this.e.a8.exportPathData(a, this.c7, "lowerShape", ["Lower", "Main"]);
            this.e.a8.exportPathData(a, this.c8, "upperShape", ["Upper"]);
            this.e.a8.exportPathData(a, this.c6, "translucentShape", ["Translucent"]);
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.pf = a;
            this.e.gy = 3;
            this.e.gz = 1;
            this.e.g0 = 4;
            this.e.e9 = false;
        }
    }
    RadialLineSeriesView.$t = /*@__PURE__*/ markType(RadialLineSeriesView, 'RadialLineSeriesView', AnchoredRadialSeriesView.$);
    return RadialLineSeriesView;
})();
